@@ -1,12 +1,10 @@
-from __future__ import print_function
-
 import os
 
 __author__ = ["petras vestartas"]
 __copyright__ = "Block Research Group - ETH Zurich"
 __license__ = "MIT License"
 __email__ = "petrasvestartas@gmail.com"
-__version__ = "0.4.2"
+__version__ = "0.9.0"
 
 HERE = os.path.dirname(__file__)
 
@@ -22,4 +20,5 @@ __all_plugins__ = [
     "compas_model.rhino",
     "compas_model.rhino.scene",
     "compas_model.notebook.scene",
+    "compas_model.viewer",
 ]
