@@ -1,5 +1,4 @@
-from .elementnode import ElementNode
-from .groupnode import GroupNode
+from .elementtree import ElementNode
 from .elementtree import ElementTree
 from .interactiongraph import InteractionGraph
 from .model import Model
@@ -8,7 +7,6 @@ from .model import Model
 __all__ = [
     "ElementNode",
     "ElementTree",
-    "GroupNode",
     "InteractionGraph",
     "Model",
 ]
